@@ -1,58 +1,88 @@
-# Author: Peter Nardi
-# Date: 11/11/21
-# License: MIT (terms at the end of this file)
-
-# Title: parser201 - Apache Access Log Parser
-
-# Imports
+"""LogParser Class."""
 
 import datetime as dt
-import enum
 import re
 import time
-
 from enum import Enum
+from enum import auto
 
 
 class TZ(Enum):
-    """Enum to determine adjustment of the timestamp property of a
-    `LogParser` object.
+    """Timestamp adjustment enum.
+
+    Enum to determine the timezone adjustment of the timestamp property
+    of a `LogParser` object.
     """
-    original = 1
-    local = 2
-    utc = 3
+
+    original = auto()
+    local = auto()
+    utc = auto()
+
+    def __eq__(self, other):
+        """Compare the values of two TZ Enums.
+
+        Parameters
+        ----------
+        other : Enum TZ
+            The right-hand side of the equality comparison.
+
+        Returns
+        -------
+        bool
+            True is two TZ Enums are equal, False otherwise.
+        """
+        return self.value == other.value
 
 
 class FMT(Enum):
-    """
+    """Format enum.
+
     Enum to determine the format for the timestamp attribute of a
     `LogParser` object.
     """
-    string = 1
-    dateobj = 2
+
+    string = auto()
+    dateobj = auto()
+
+    def __eq__(self, other):
+        """Compare the values of two FMT Enums.
+
+        Parameters
+        ----------
+        other : Enum FMT
+            The right-hand side of the equality comparison.
+
+        Returns
+        -------
+        bool
+            True is two FMT Enums are equal, False otherwise.
+        """
+        return self.value == other.value
 
 
 class LogParser:
-    """The class initializer takes a single line (as a string) from an
-    Apache log file and extracts the individual fields into attributes
-    within an object.
+    """The `LogParser` Class.
+
+    The class initializer takes a single line (as a string) from an
+    Apache access log file and extracts the individual fields into
+    attributes within an object.
 
     Arguments
     ---------
     line : str
         A single line from an Apache access log.
     timezone : {TZ.original, TZ.utc, TZ.local}, optional
-        During parsing, adjust the timestamp of the `LogParser` object to
-        match a particular timezone. Default is *TZ.original*
-        (no adjustment). *TZ.local* adjusts the timestamp to the
-        timezone currently selected on the machine running the code.
-        *TZ.utc* adjusts the timestamp to
-        [UTC](https:\
+        During parsing, adjust the timestamp of the `LogParser` object
+        to match a particular timezone. Default is *TZ.original* (no
+        adjustment). *TZ.local* adjusts the timestamp to the timezone
+        currently selected on the machine running the code. *TZ.utc*
+        adjusts the timestamp to [UTC](https:\
         //en.wikipedia.org/wiki/Coordinated_Universal_Time).
-    format : {FMT.string, FMT.dateobj}, optional
-        Set the format of the timestamp attribute of the `LogParser`
-        object. Default is *FMT.string*. Using *FMT.dateobj* will store
-        the timestamp attribute as a Python [datetime object](https:\
+    dtsformat : {FMT.string, FMT.dateobj}, optional
+        Set the format of the date timestamp attribute of the
+        `LogParser` object. Default is *FMT.string*. Using *FMT.dateobj*
+        will store the timestamp attribute as a Python
+        [datetime object](https:\
         //docs.python.org/3/library/datetime.html).
 
     Attributes
@@ -70,7 +100,7 @@ class LogParser:
     statuscode : int
         The status code sent from the server to the client (`200`,
         `404`, etc.).
-    timestamp : str or datetime object
+    timestamp : (str | datetime object)
         The date and time of the request in the following format:
 
         `dd/MMM/YYYY:HH:MM:SS –hhmm`
@@ -99,18 +129,17 @@ class LogParser:
     >>> lp = LogParser(line)
 
     Creating a `LogParser` object with custom options. The timestamp
-    attribute will adjusted to the timezone on the local machine and
+    attribute will be adjusted to the timezone on the local machine and
     will be stored as a Python [datetime object](https:\
     //docs.python.org/3/library/datetime.html).
     >>> from parser201 import LogParser, TZ, FMT
     >>> line = # a line from an Apache access log
-    >>> lp = LogParser(line, timezone=TZ.local, format=FMT.dateobj)
+    >>> lp = LogParser(line, timezone=TZ.local, dtsformat=FMT.dateobj)
     """
-    # ---------------------------------------------------------------------
 
-    def __init__(self, line, timezone=TZ.original, format=FMT.string):
+    def __init__(self, line, timezone=TZ.original, dtsformat=FMT.string):
 
-        # Initialize attributes
+        # Establish attributes
         self.ipaddress = ''
         self.userid = ''
         self.username = ''
@@ -123,7 +152,6 @@ class LogParser:
 
         # Initial check. If the line passed to the initializer is not a string
         # (type == str), then return an empty LogParser object.
-
         if type(line) != str:
             self.__noneFields()
             return
@@ -133,13 +161,11 @@ class LogParser:
         # this: "". The regex to pull out agent strings between quotes will
         # incorrectly ignore that field, rather than returning an empty string.
         # Replace "" with "-" to prevent that.
-
         clean = line.replace('\"\"', '\"-\"')
 
         # agentStrings: This part of the regex:(?<!\\)\" is a negative
         # lookbehind assertion. It says, "end with a quote mark, unless that
         # quote mark is preceded by an escape character '\'"
-
         agentStrings = re.findall(r'\"(.+?)(?<!\\)\"', clean)
 
         # The next one's tricky. We're looking to extract the statuscode and
@@ -152,7 +178,6 @@ class LogParser:
         # cast to them int; else set them to 0. If any of this fails, then
         # consider that we have a malformed log line and set all the properties
         # to None.
-
         try:
             L = clean.split(' ')
             i = [j for j in range(len(L)) if L[j].isnumeric()][0]
@@ -167,7 +192,6 @@ class LogParser:
 
         # Set properties. If any of these fail, then consider that we have a
         # malformed log line and set all the properties to None.
-
         try:
             self.ipaddress = first3[0]
             self.userid = first3[1]
@@ -183,15 +207,14 @@ class LogParser:
             self.__noneFields()
             return
 
-        # Process date/time stamp and adjust timezone/format as indicated
-
-        if timezone == TZ.original and format == FMT.string:
+        # Process date/time stamp and adjust timezone/dtsformat as indicated
+        if timezone == TZ.original and dtsformat == FMT.string:
             return
 
         try:
             dateobj = dt.datetime.strptime(self.timestamp,
                                            '%d/%b/%Y:%H:%M:%S %z')
-        except ValueError as e:
+        except ValueError:
             self.__noneFields()
             return
 
@@ -199,7 +222,6 @@ class LogParser:
 
         if timezone == TZ.original:
             pass
-
         elif timezone == TZ.local:
             zoneString = time.strftime('%z')
             # First convert to GMT
@@ -209,44 +231,29 @@ class LogParser:
             zoneObject = dt.timezone(dt.timedelta(hours=hh*sign, minutes=mm))
             dateobj = dateobj + (sign*dt.timedelta(hours=hh, minutes=mm))
             dateobj = dateobj.replace(tzinfo=zoneObject)
-
-        elif timezone == TZ.utc:
+        else:  # TZ == utc
             dateobj = dateobj + (-1*sign*dt.timedelta(hours=hh, minutes=mm))
             sign, hh, mm = self.__decomposeTZ('+0000')
             zoneObject = dt.timezone(dt.timedelta(hours=0, minutes=0))
             dateobj = dateobj.replace(tzinfo=zoneObject)
 
-        else:  # pragma no cover
-            pass
-
-        # ---------------------------------------
-
-        if format == FMT.string:
+        if dtsformat == FMT.string:
             self.timestamp = dateobj.strftime('%d/%b/%Y:%H:%M:%S %z')
-
-        elif format == FMT.dateobj:
+        else:  # dtsformat == FMT.dateobj
             self.timestamp = dateobj
 
-        else:  # pragma no cover
-            return
-
         return
 
-    # ---------------------------------------------------------------------
-
-    # Method to set every field to None, in the event of a corrupted log line.
-
     def __noneFields(self):
+        """Set all properties to None."""
         for property in [p for p in dir(self) if not p.startswith('_')]:
             setattr(self, property, None)
         return
 
-    # ---------------------------------------------------------------------
-
-    # Method for string rendering of a LogParser object
-
     def __str__(self):
-        """The class provides a `__str__` method which renders a
+        """`LogParser` class str method.
+
+        The class provides a `__str__` method which renders a
         `LogParser` object as string suitable for display.
 
         Examples
@@ -279,42 +286,14 @@ class LogParser:
         # Build the string in the same order as the labels.
         for label in labels:
             L.append(f'{label:>{padding}}: {getattr(self, label)}')
-
         return '\n'.join(L)
 
-    # ---------------------------------------------------------------------
-
     def __decomposeTZ(self, zone):
+        """Decompose a time zone into +/-, hrs, and mins."""
         leader, hrs, mins = zone[-5], zone[-4:-2], zone[-2:]
         sign = -1 if leader == '-' else 1
         return sign, int(hrs), int(mins)
 
 
-# ---------------------------------------------------------------------
-
-
 if __name__ == '__main__':  # pragma no cover
     pass
-
-# ---------------------------------------------------------------------
-
-# MIT License
-#
-# Copyright (c) 2020-2021 Peter Nardi
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions: # The above
-# copyright notice and this permission notice shall be included in all copies
-# or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
